@@ -70,10 +70,10 @@ static bool read_plane(BitstreamRange* range,
   if (!range->prepare_read(static_cast<size_t>(width) * height)) {
     return false;
   }
-  if (!image->add_plane(channel, width, height, bit_depth)) {
+  if (auto err = image->add_plane(channel, width, height, bit_depth, heif_get_disabled_security_limits())) {
     return false;
   }
-  uint32_t stride;
+  size_t stride;
   uint8_t* plane = image->get_plane(channel, &stride);
   assert(stride >= width);
   auto stream = range->get_istream();
@@ -96,10 +96,10 @@ static bool read_plane_interleaved(BitstreamRange* range,
   if (!range->prepare_read(static_cast<size_t>(width) * height * comps)) {
     return false;
   }
-  if (!image->add_plane(channel, width, height, bit_depth)) {
+  if (auto err = image->add_plane(channel, width, height, bit_depth, heif_get_disabled_security_limits())) {
     return false;
   }
-  uint32_t stride;
+  size_t stride;
   uint8_t* plane = image->get_plane(channel, &stride);
   assert(stride >= width * comps);
   auto stream = range->get_istream();
@@ -250,19 +250,23 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t* data, size_t size)
   int output_bpp = 0; // Same as input.
   heif_encoding_options* options = heif_encoding_options_alloc();
 
-  auto out_image = convert_colorspace(in_image,
-                                      static_cast<heif_colorspace>(out_colorspace),
-                                      static_cast<heif_chroma>(out_chroma),
-                                      nullptr,
-                                      output_bpp,
-                                      options->color_conversion_options);
+  auto out_image_result = convert_colorspace(in_image,
+                                             static_cast<heif_colorspace>(out_colorspace),
+                                             static_cast<heif_chroma>(out_chroma),
+                                             nullptr,
+                                             output_bpp,
+                                             options->color_conversion_options,
+                                             heif_get_disabled_security_limits());
+
   heif_encoding_options_free(options);
 
-  if (!out_image) {
+  if (out_image_result.error) {
     // Conversion is not supported.
     return 0;
   }
 
+  auto out_image = *out_image_result;
+
   assert(out_image->get_width() == width);
   assert(out_image->get_height() == height);
   assert(out_image->get_chroma_format() ==
