@@ -28,6 +28,7 @@
 #include <cstring>
 #include <memory>
 #include <vector>
+#include <utility>
 #include <algorithm>
 
 
@@ -65,7 +66,7 @@ struct heif_error heif_context_get_region_item(const struct heif_context* contex
 
   heif_region_item* item = new heif_region_item();
   item->context = context->context;
-  item->region_item = r;
+  item->region_item = std::move(r);
   *out = item;
 
   return heif_error_success;
@@ -133,7 +134,7 @@ struct heif_error heif_image_handle_add_region_item(struct heif_image_handle* im
   if (out_region_item) {
     heif_region_item* item = new heif_region_item();
     item->context = image_handle->context;
-    item->region_item = regionItem;
+    item->region_item = std::move(regionItem);
 
     *out_region_item = item;
   }
@@ -333,8 +334,8 @@ struct heif_error heif_region_item_add_region_inline_mask(struct heif_region_ite
   region->mask_data.resize((width * height + 7) / 8);
   memset(region->mask_data.data(), 0, region->mask_data.size());
 
-  uint32_t mask_height = (uint32_t)heif_image_get_height(mask_image, heif_channel_Y);
-  uint32_t mask_width = (uint32_t)heif_image_get_width(mask_image, heif_channel_Y);
+  uint32_t mask_height = mask_image->image->get_height();
+  uint32_t mask_width = mask_image->image->get_width();
   int stride;
   uint8_t* p = heif_image_get_plane(mask_image, heif_channel_Y, &stride);
   uint64_t pixel_index = 0;
