@@ -23,12 +23,15 @@
 #include <utility>
 #include <cstring>
 #include <cassert>
+
+#if ((defined(__GNUC__) && !defined(__clang__) && !defined(__INTEL_COMPILER) && !defined(__PGI)) && __GNUC__ < 9) || (defined(__clang__) && __clang_major__ < 10)
+#include <type_traits>
+#else
 #include <bit>
+#endif
 
 #define MAX_UVLC_LEADING_ZEROS 20
 
-#define AVOID_FUZZER_FALSE_POSITIVE 0
-
 
 StreamReader_istream::StreamReader_istream(std::unique_ptr<std::istream>&& istr)
     : m_istr(std::move(istr))
@@ -507,7 +510,10 @@ uint32_t BitReader::get_bits(int n)
   uint64_t val = nextbits;
   val >>= 64 - n;
 
-  if (AVOID_FUZZER_FALSE_POSITIVE) nextbits &= (0xffffffffffffffffULL >> n);
+#if AVOID_FUZZER_FALSE_POSITIVE
+  // Shifting an unsigned integer left such that some MSBs fall out is well defined in C++ despite the fuzzer claiming otherwise.
+  nextbits &= (0xffffffffffffffffULL >> n);
+#endif
 
   nextbits <<= n;
   nextbits_cnt -= n;
@@ -595,14 +601,20 @@ void BitReader::skip_bits(int n)
     refill();
   }
 
-  if (AVOID_FUZZER_FALSE_POSITIVE) nextbits &= (0xffffffffffffffffULL >> n);
+#if AVOID_FUZZER_FALSE_POSITIVE
+  nextbits &= (0xffffffffffffffffULL >> n);
+#endif
+
   nextbits <<= n;
   nextbits_cnt -= n;
 }
 
 void BitReader::skip_bits_fast(int n)
 {
-  if (AVOID_FUZZER_FALSE_POSITIVE) nextbits &= (0xffffffffffffffffULL >> n);
+#if AVOID_FUZZER_FALSE_POSITIVE
+  nextbits &= (0xffffffffffffffffULL >> n);
+#endif
+
   nextbits <<= n;
   nextbits_cnt -= n;
 }
@@ -611,7 +623,10 @@ void BitReader::skip_to_byte_boundary()
 {
   int nskip = (nextbits_cnt & 7);
 
-  if (AVOID_FUZZER_FALSE_POSITIVE) nextbits &= (0xffffffffffffffffULL >> nskip);
+#if AVOID_FUZZER_FALSE_POSITIVE
+  nextbits &= (0xffffffffffffffffULL >> nskip);
+#endif
+
   nextbits <<= nskip;
   nextbits_cnt -= nskip;
 }
