@@ -260,6 +260,8 @@ public:
 
   void set_is_essential(bool flag) { m_is_essential = flag; }
 
+  virtual bool is_transformative_property() const { return false; } // only used for properties
+
 protected:
   virtual Error parse(BitstreamRange& range, const heif_security_limits* limits);
 
@@ -802,6 +804,9 @@ public:
 
   void insert_entries_from_other_ipma_box(const Box_ipma& b);
 
+  // sorts properties such that descriptive properties precede the transformative properties
+  void sort_properties(const std::shared_ptr<Box_ipco>&);
+
 protected:
   Error parse(BitstreamRange& range, const heif_security_limits*) override;
 
@@ -854,6 +859,8 @@ public:
 
   bool is_essential() const override { return true; }
 
+  bool is_transformative_property() const override { return true; }
+
   std::string dump(Indent&) const override;
 
   int get_rotation_ccw() const { return m_rotation; }
@@ -883,6 +890,8 @@ public:
 
   bool is_essential() const override { return true; }
 
+  bool is_transformative_property() const override { return true; }
+
   heif_transform_mirror_direction get_mirror_direction() const { return m_axis; }
 
   void set_mirror_direction(heif_transform_mirror_direction dir) { m_axis = dir; }
@@ -911,6 +920,8 @@ public:
 
   bool is_essential() const override { return true; }
 
+  bool is_transformative_property() const override { return true; }
+
   std::string dump(Indent&) const override;
 
   int left_rounded(uint32_t image_width) const;  // first column
