@@ -34,11 +34,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 
@@ -50,11 +51,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 
@@ -66,11 +68,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 
@@ -82,11 +85,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 
@@ -98,11 +102,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 
@@ -114,11 +119,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 
