@@ -36,11 +36,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 
@@ -52,11 +53,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 
@@ -68,11 +70,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 
@@ -84,11 +87,12 @@ public:
                          const ColorState& target_state,
                          const heif_color_conversion_options& options) const override;
 
-  std::shared_ptr<HeifPixelImage>
+  Result<std::shared_ptr<HeifPixelImage>>
   convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                      const ColorState& input_state,
                      const ColorState& target_state,
-                     const heif_color_conversion_options& options) const override;
+                     const heif_color_conversion_options& options,
+                     const heif_security_limits* limits) const override;
 };
 
 #endif //LIBHEIF_COLORCONVERSION_YUV2RGB_H
