@@ -51,7 +51,7 @@ public:
   Error on_load_file() override;
 
 protected:
-  std::shared_ptr<Decoder> get_decoder() const override;
+  Result<std::shared_ptr<Decoder>> get_decoder() const override;
 
   Result<std::vector<uint8_t>> read_bitstream_configuration_data() const override;
 
