@@ -14,7 +14,7 @@ var HeifImage = function(handle) {
 
 HeifImage.prototype.free = function() {
     if (this.handle) {
-        libheif.heif_image_handle_release(this.handle);
+        Module.heif_image_handle_release(this.handle);
         this.handle = null;
     }
 };
@@ -24,8 +24,8 @@ HeifImage.prototype._ensureImage = function() {
         return;
     }
 
-    var img = libheif.heif_js_decode_image(this.handle,
-        libheif.heif_colorspace_YCbCr, libheif.heif_chroma_420);
+    var img = Module.heif_js_decode_image(this.handle,
+      Module.heif_colorspace.heif_colorspace_YCbCr, Module.heif_chroma.heif_chroma_420);
     if (!img || img.code) {
         console.log("Decoding image failed", this.handle, img);
         return;
@@ -36,17 +36,17 @@ HeifImage.prototype._ensureImage = function() {
     this.img = img;
 
     if (img.alpha !== undefined) {
-	this.alpha = new Uint8Array(StringToArrayBuffer(img.alpha));
-	delete img.alpha;
+        this.alpha = new Uint8Array(StringToArrayBuffer(img.alpha));
+        delete img.alpha;
     }
 };
 
 HeifImage.prototype.get_width = function() {
-    return libheif.heif_image_handle_get_width(this.handle);
+    return Module.heif_image_handle_get_width(this.handle);
 };
 
 HeifImage.prototype.get_height = function() {
-    return libheif.heif_image_handle_get_height(this.handle);
+    return Module.heif_image_handle_get_height(this.handle);
 };
 
 HeifImage.prototype.is_primary = function() {
@@ -63,8 +63,8 @@ HeifImage.prototype.display = function(image_data, callback) {
         // If image hasn't been loaded yet, decode the image
 
         if (!this.img) {
-            var img = libheif.heif_js_decode_image2(this.handle,
-                libheif.heif_colorspace_RGB, libheif.heif_chroma_interleaved_RGBA);
+            var img = Module.heif_js_decode_image2(this.handle,
+              Module.heif_colorspace.heif_colorspace_RGB, Module.heif_chroma.heif_chroma_interleaved_RGBA);
             if (!img || img.code) {
                 console.log("Decoding image failed", this.handle, img);
 
@@ -73,14 +73,13 @@ HeifImage.prototype.display = function(image_data, callback) {
             }
 
             for (let c of img.channels) {
-                if (c.id == libheif.heif_channel_interleaved) {
+                if (c.id == Module.heif_channel.heif_channel_interleaved) {
 
                     // copy image into output array
 
-                    if (c.stride == c.width*4) {
+                    if (c.stride == c.width * 4) {
                         image_data.data.set(c.data);
-                    }
-                    else {
+                    } else {
                         for (let y = 0; y < c.height; y++) {
                             let slice = c.data.slice(y * c.stride, y * c.stride + c.width * 4);
                             let offset = y * c.width * 4;
@@ -90,7 +89,7 @@ HeifImage.prototype.display = function(image_data, callback) {
                 }
             }
 
-            libheif.heif_image_release(img.image);
+            Module.heif_image_release(img.image);
         }
 
         callback(image_data);
@@ -103,32 +102,31 @@ var HeifDecoder = function() {
 
 HeifDecoder.prototype.decode = function(buffer) {
     if (this.decoder) {
-        libheif.heif_context_free(this.decoder);
+        Module.heif_context_free(this.decoder);
     }
-    this.decoder = libheif.heif_context_alloc();
+    this.decoder = Module.heif_context_alloc();
     if (!this.decoder) {
         console.log("Could not create HEIF context");
         return [];
     }
-    var error = libheif.heif_context_read_from_memory(this.decoder, buffer);
-    if (error.code !== libheif.heif_error_Ok) {
-        console.log("Could not parse HEIF file", error);
+    var error = Module.heif_context_read_from_memory(this.decoder, buffer);
+    if (error.code !== Module.heif_error_code.heif_error_Ok) {
+        console.log("Could not parse HEIF file", error.message);
         return [];
     }
 
-    var ids = libheif.heif_js_context_get_list_of_top_level_image_IDs(this.decoder);
+    var ids = Module.heif_js_context_get_list_of_top_level_image_IDs(this.decoder);
     if (!ids || ids.code) {
         console.log("Error loading image ids", ids);
         return [];
-    }
-    else if (!ids.length) {
+    } else if (!ids.length) {
         console.log("No images found");
         return [];
     }
 
     var result = [];
     for (var i = 0; i < ids.length; i++) {
-        var handle = libheif.heif_js_context_get_image_handle(this.decoder, ids[i]);
+        var handle = Module.heif_js_context_get_image_handle(this.decoder, ids[i]);
         if (!handle || handle.code) {
             console.log("Could not get image data for id", ids[i], handle);
             continue;
@@ -139,61 +137,39 @@ HeifDecoder.prototype.decode = function(buffer) {
     return result;
 };
 
-var libheif = {
-    // Expose high-level API.
-    /** @expose */
-    HeifDecoder: HeifDecoder,
-
-    // Expose low-level API.
-    /** @expose */
-    fourcc: function(s) {
-        return s.charCodeAt(0) << 24 |
-            s.charCodeAt(1) << 16 |
-            s.charCodeAt(2) << 8 |
-            s.charCodeAt(3);
-    }
-};
-
-// don't pollute the global namespace
-delete this['Module'];
-
-// On IE this function is called with "undefined" as first parameter. Override
-// with a version that supports this behaviour.
-function createNamedFunction(name, body) {
-    if (!name) {
-      name = "function_" + (new Date());
-    }
-    name = makeLegalFunctionName(name);
-    /*jshint evil:true*/
-    return new Function(
-        "body",
-        "return function " + name + "() {\n" +
-        "    \"use strict\";" +
-        "    return body.apply(this, arguments);\n" +
-        "};\n"
-    )(body);
+var fourcc = function(s) {
+    return s.charCodeAt(0) << 24 |
+      s.charCodeAt(1) << 16 |
+      s.charCodeAt(2) << 8 |
+      s.charCodeAt(3);
 }
 
-var root = this;
+Module.HeifImage = HeifImage;
+Module.HeifDecoder = HeifDecoder;
+Module.fourcc = fourcc;
 
-if (typeof exports !== 'undefined') {
-    if (typeof module !== 'undefined' && module.exports) {
-        /** @expose */
-        exports = module.exports = libheif;
+// Expose enum values.
+const enums = [
+    'heif_error_code',
+    'heif_suberror_code',
+    'heif_compression_format',
+    'heif_chroma',
+    'heif_colorspace',
+    'heif_channel'
+];
+for (const e of enums) {
+    for (const key in Module[e]) {
+        if (!Module[e].hasOwnProperty(key) || key === 'values') {
+            continue;
+        }
+        Module[key] = Module[e][key];
     }
-    /** @expose */
-    exports.libheif = libheif;
-} else {
-    /** @expose */
-    root.libheif = libheif;
 }
 
-if (typeof define === "function" && define.amd) {
-    /** @expose */
-    define([], function() {
-        return libheif;
-    });
+// Expose internal C API.
+for (const key in Module) {
+    if (key.indexOf('_heif_') !== 0 || Module[key.slice(1)] !== undefined) {
+        continue;
+    }
+    Module[key.slice(1)] = Module[key];
 }
-
-// NOTE: wrapped inside "(function() {" block from pre.js
-}).call(this);
